==> aTunes_1.13.2.tar.gz: aTunes/src/net/sourceforge/atunes/gui/views/controls/playList/PlayListTable.java <==
/*
 * aTunes 1.13.2
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.views.controls.playList;

import java.awt.dnd.DnDConstants;
import java.awt.dnd.DragGestureEvent;
import java.awt.dnd.DragGestureListener;
import java.awt.dnd.DragSource;
import java.awt.dnd.DragSourceDragEvent;
import java.awt.dnd.DragSourceDropEvent;
import java.awt.dnd.DragSourceEvent;
import java.awt.dnd.DragSourceListener;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ArrayList;
import java.util.List;

import javax.swing.DropMode;
import javax.swing.ImageIcon;
import javax.swing.InputMap;
import javax.swing.JComponent;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.JSeparator;
import javax.swing.JTable;
import javax.swing.KeyStroke;
import javax.swing.ListSelectionModel;

import net.sourceforge.atunes.gui.Fonts;
import net.sourceforge.atunes.gui.GuiUtils;
import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.model.PlayListColumnModel;
import net.sourceforge.atunes.gui.model.PlayListTableModel;
import net.sourceforge.atunes.gui.model.TransferableList;
import net.sourceforge.atunes.kernel.actions.Actions;
import net.sourceforge.atunes.kernel.actions.Add100RandomSongsAction;
import net.sourceforge.atunes.kernel.actions.Add100SongsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add100UnplayedSongsAction;
import net.sourceforge.atunes.kernel.actions.Add10AlbumsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add10ArtistsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add10RandomSongsAction;
import net.sourceforge.atunes.kernel.actions.Add10SongsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add10UnplayedSongsAction;
import net.sourceforge.atunes.kernel.actions.Add1AlbumsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add1ArtistsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add50RandomSongsAction;
import net.sourceforge.atunes.kernel.actions.Add50SongsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add50UnplayedSongsAction;
import net.sourceforge.atunes.kernel.actions.Add5AlbumsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add5ArtistsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.AutoSetCoversAction;
import net.sourceforge.atunes.kernel.actions.AutoSetGenresAction;
import net.sourceforge.atunes.kernel.actions.AutoSetLyricsAction;
import net.sourceforge.atunes.kernel.actions.AutoSetTagFromFileNamePatternAction;
import net.sourceforge.atunes.kernel.actions.AutoSetTitlesAction;
import net.sourceforge.atunes.kernel.actions.AutoSetTracksAction;
import net.sourceforge.atunes.kernel.actions.ClearPlayListAction;
import net.sourceforge.atunes.kernel.actions.CreatePlayListWithSelectedAlbumsAction;
import net.sourceforge.atunes.kernel.actions.CreatePlayListWithSelectedArtistsAction;
import net.sourceforge.atunes.kernel.actions.EditTagAction;
import net.sourceforge.atunes.kernel.actions.LoadPlayListAction;
import net.sourceforge.atunes.kernel.actions.MoveDownAction;
import net.sourceforge.atunes.kernel.actions.MoveToBottomAction;
import net.sourceforge.atunes.kernel.actions.MoveToTopAction;
import net.sourceforge.atunes.kernel.actions.MoveUpAction;
import net.sourceforge.atunes.kernel.actions.OpenFolderAction;
import net.sourceforge.atunes.kernel.actions.PlayAction;
import net.sourceforge.atunes.kernel.actions.RemoveFromPlayListAction;
import net.sourceforge.atunes.kernel.actions.SavePlayListAction;
import net.sourceforge.atunes.kernel.actions.SetPlayListSelectionAsFavoriteAlbumAction;
import net.sourceforge.atunes.kernel.actions.SetPlayListSelectionAsFavoriteArtistAction;
import net.sourceforge.atunes.kernel.actions.SetPlayListSelectionAsFavoriteSongAction;
import net.sourceforge.atunes.kernel.actions.ShowPlayListItemInfoAction;
import net.sourceforge.atunes.kernel.actions.ShufflePlayListAction;
import net.sourceforge.atunes.kernel.actions.TogglePlayListFilterAction;
import net.sourceforge.atunes.kernel.modules.draganddrop.PlayListDragableRow;
import net.sourceforge.atunes.kernel.modules.playlist.PlayListHandler;
import net.sourceforge.atunes.model.AudioObject;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The Class PlayListTable.
 */
public class PlayListTable extends JTable implements DragSourceListener, DragGestureListener {

    /**
     * The Enum PlayState.
     */
    public enum PlayState {

        /** The STOPPED. */
        STOPPED,

        /** The PLAYING. */
        PLAYING,

        /** The PAUSED. */
        PAUSED,

        /**
         * When it's not the active play list
         */
        NONE;

        public static ImageIcon getPlayStateIcon(PlayState state) {
            switch (state) {
            case PLAYING:
                return ImageLoader.PLAY_TINY;
            case STOPPED:
                return ImageLoader.STOP_TINY;
            case PAUSED:
                return ImageLoader.PAUSE_TINY;
            case NONE:
                return ImageLoader.EMPTY;
            default:
                return ImageLoader.EMPTY;
            }
        }
    }

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 9209069236823917569L;

    /** The play state. */
    private PlayState playState = PlayState.STOPPED;

    /** The menu. */
    private JPopupMenu menu;

    /** The right menu. */
    JPopupMenu rightMenu;

    /** The arrange columns. */
    private JMenuItem arrangeColumns;

    /** The listeners. */
    List<PlayListColumnClickedListener> listeners = new ArrayList<PlayListColumnClickedListener>();

    /**
     * Drag source for this play list to drag songs to device
     */
    private DragSource dragSource;

    /**
     * Instantiates a new play list table.
     */
    public PlayListTable() {
        super();
        setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        setShowGrid(false);
        setDropMode(DropMode.ON);

        // Add mouse click listener on table header
        getTableHeader().addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                // Use left button to sort
                if (e.getButton() == MouseEvent.BUTTON1) {
                    PlayListColumnModel colModel = (PlayListColumnModel) getColumnModel();
                    int column = colModel.getColumnIndexAtPosition(e.getX());
                    if (column >= 0) {
                        Column columnClicked = ((PlayListColumnModel) getColumnModel()).getColumnObject(column);
                        for (int i = 0; i < listeners.size(); i++) {
                            listeners.get(i).columnClicked(columnClicked);
                        }
                    }
                }
                // Use right button to arrange columns
                else if (e.getButton() == MouseEvent.BUTTON3) {
                    rightMenu.show(PlayListTable.this, e.getX(), e.getY());
                }
            }
        });

        // Set table model
        setModel(new PlayListTableModel());

        // Set column model
        setColumnModel(new PlayListColumnModel(this));

        // Disable autoresize, as we will control it
        setAutoResizeMode(JTable.AUTO_RESIZE_OFF);

        // Set renderers
        PlayListRenderers.addRenderers(this);

        // Remove enter key event, which moves selection down
        getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT).put(KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), "none");

        // Remove F2 key event
        InputMap im = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
        KeyStroke f2 = KeyStroke.getKeyStroke(KeyEvent.VK_F2, 0);
        im.put(f2, "none");

        rightMenu = new JPopupMenu();
        arrangeColumns = new JMenuItem(LanguageTool.getString("ARRANGE_COLUMNS"));
        rightMenu.add(arrangeColumns);

        menu = new JPopupMenu();

        menu.add(Actions.getAction(PlayAction.class));
        menu.add(Actions.getAction(ShowPlayListItemInfoAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(OpenFolderAction.class));
        menu.add(new JSeparator());
        JMenu tagMenu = setMenu(new JMenu(LanguageTool.getString("TAGS")));
        tagMenu.add(Actions.getAction(EditTagAction.class));
        tagMenu.add(new JSeparator());
        tagMenu.add(Actions.getAction(AutoSetTagFromFileNamePatternAction.class));
        tagMenu.add(new JSeparator());
        tagMenu.add(Actions.getAction(AutoSetLyricsAction.class));
        tagMenu.add(Actions.getAction(AutoSetTitlesAction.class));
        tagMenu.add(Actions.getAction(AutoSetTracksAction.class));
        tagMenu.add(Actions.getAction(AutoSetGenresAction.class));
        tagMenu.add(Actions.getAction(AutoSetCoversAction.class));
        menu.add(tagMenu);
        menu.add(new JSeparator());
        menu.add(Actions.getAction(SavePlayListAction.class));
        menu.add(Actions.getAction(LoadPlayListAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(RemoveFromPlayListAction.class));
        menu.add(Actions.getAction(ClearPlayListAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(MoveToTopAction.class));
        menu.add(Actions.getAction(MoveUpAction.class));
        menu.add(Actions.getAction(MoveDownAction.class));
        menu.add(Actions.getAction(MoveToBottomAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(ShufflePlayListAction.class));
        menu.add(new JSeparator());
        JMenu smartPlayList = new JMenu(LanguageTool.getString("SMART_PLAYLIST"));
        smartPlayList.add(Actions.getAction(Add10RandomSongsAction.class));
        smartPlayList.add(Actions.getAction(Add50RandomSongsAction.class));
        smartPlayList.add(Actions.getAction(Add100RandomSongsAction.class));
        smartPlayList.add(new JSeparator());
        smartPlayList.add(Actions.getAction(Add10SongsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add50SongsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add100SongsMostPlayedAction.class));
        smartPlayList.add(new JSeparator());
        smartPlayList.add(Actions.getAction(Add1AlbumsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add5AlbumsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add10AlbumsMostPlayedAction.class));
        smartPlayList.add(new JSeparator());
        smartPlayList.add(Actions.getAction(Add1ArtistsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add5ArtistsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add10ArtistsMostPlayedAction.class));
        smartPlayList.add(new JSeparator());
        smartPlayList.add(Actions.getAction(Add10UnplayedSongsAction.class));
        smartPlayList.add(Actions.getAction(Add50UnplayedSongsAction.class));
        smartPlayList.add(Actions.getAction(Add100UnplayedSongsAction.class));
        menu.add(smartPlayList);
        menu.add(new JSeparator());
        menu.add(Actions.getAction(SetPlayListSelectionAsFavoriteSongAction.class));
        menu.add(Actions.getAction(SetPlayListSelectionAsFavoriteAlbumAction.class));
        menu.add(Actions.getAction(SetPlayListSelectionAsFavoriteArtistAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(CreatePlayListWithSelectedArtistsAction.class));
        menu.add(Actions.getAction(CreatePlayListWithSelectedAlbumsAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(TogglePlayListFilterAction.class));
        GuiUtils.applyComponentOrientation(menu);

        // Create drag source and set listener
        dragSource = new DragSource();
        dragSource.createDefaultDragGestureRecognizer(this, DnDConstants.ACTION_COPY, this);
    }

    /**
     * Adds the play list column clicked listener.
     * 
     * @param l
     *            the l
     */
    public void addPlayListColumnClickedListener(PlayListColumnClickedListener l) {
        listeners.add(l);
    }

    /**
     * Gets the arrange columns.
     * 
     * @return the arrangeColumns
     */
    public JMenuItem getArrangeColumns() {
        return arrangeColumns;
    }

    /**
     * Gets the menu.
     * 
     * @return the menu
     */
    public JPopupMenu getMenu() {
        return menu;
    }

    /**
     * Gets the play state.
     * 
     * @return the play state
     */
    public PlayState getPlayState() {
        return playState;
    }

    /**
     * Sets the menu.
     * 
     * @param item
     *            the item
     * 
     * @return the j menu
     */
    private JMenu setMenu(JMenu item) {
        item.setFont(Fonts.PLAY_LIST_FONT);
        return item;
    }

    /**
     * Sets the play state.
     * 
     * @param playState
     *            the new play state
     */
    public void setPlayState(PlayState playState) {
        this.playState = playState;
        revalidate();
        repaint();
    }

    @Override
    public void dragDropEnd(DragSourceDropEvent dsde) {
    }

    @Override
    public void dragEnter(DragSourceDragEvent dsde) {
    }

    @Override
    public void dragExit(DragSourceEvent dse) {
    }

    @Override
    public void dragGestureRecognized(DragGestureEvent dge) {
        // Only allow drag events initiated with left mouse button
        InputEvent event = dge.getTriggerEvent();
        if (!(event instanceof MouseEvent) || ((MouseEvent) event).getButton() != MouseEvent.BUTTON1) {
            return;
        }

        // Get selected rows, add PlayListDragableRow objects to a list and start a drag event
        int[] selectedRows = getSelectedRows();
        List<Object> itemsToDrag = new ArrayList<Object>();
        for (int i : selectedRows) {
            AudioObject obj = PlayListHandler.getInstance().getCurrentPlayList(true).get(i);
            itemsToDrag.add(new PlayListDragableRow(obj, i));
        }
        TransferableList<Object> items = new TransferableList<Object>(itemsToDrag);
        dragSource.startDrag(dge, DragSource.DefaultCopyDrop, items, this);
    }

    @Override
    public void dragOver(DragSourceDragEvent dsde) {
    }

    @Override
    public void dropActionChanged(DragSourceDragEvent dsde) {
    }
}

==> aTunes_1.13.6.tar.gz: aTunes/src/net/sourceforge/atunes/gui/views/controls/playList/PlayListTable.java <==
/*
 * aTunes 1.13.6
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.views.controls.playList;

import java.awt.dnd.DnDConstants;
import java.awt.dnd.DragGestureEvent;
import java.awt.dnd.DragGestureListener;
import java.awt.dnd.DragSource;
import java.awt.dnd.DragSourceDragEvent;
import java.awt.dnd.DragSourceDropEvent;
import java.awt.dnd.DragSourceEvent;
import java.awt.dnd.DragSourceListener;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ArrayList;
import java.util.List;

import javax.swing.DropMode;
import javax.swing.ImageIcon;
import javax.swing.InputMap;
import javax.swing.JComponent;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.JSeparator;
import javax.swing.JTable;
import javax.swing.KeyStroke;
import javax.swing.ListSelectionModel;

import net.sourceforge.atunes.gui.Fonts;
import net.sourceforge.atunes.gui.GuiUtils;
import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.model.PlayListColumnModel;
import net.sourceforge.atunes.gui.model.PlayListTableModel;
import net.sourceforge.atunes.gui.model.TransferableList;
import net.sourceforge.atunes.kernel.actions.Actions;
import net.sourceforge.atunes.kernel.actions.Add100RandomSongsAction;
import net.sourceforge.atunes.kernel.actions.Add100SongsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add100UnplayedSongsAction;
import net.sourceforge.atunes.kernel.actions.Add10AlbumsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add10ArtistsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add10RandomSongsAction;
import net.sourceforge.atunes.kernel.actions.Add10SongsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add10UnplayedSongsAction;
import net.sourceforge.atunes.kernel.actions.Add1AlbumsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add1ArtistsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add50RandomSongsAction;
import net.sourceforge.atunes.kernel.actions.Add50SongsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add50UnplayedSongsAction;
import net.sourceforge.atunes.kernel.actions.Add5AlbumsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.Add5ArtistsMostPlayedAction;
import net.sourceforge.atunes.kernel.actions.AutoSetCoversAction;
import net.sourceforge.atunes.kernel.actions.AutoSetGenresAction;
import net.sourceforge.atunes.kernel.actions.AutoSetLyricsAction;
import net.sourceforge.atunes.kernel.actions.AutoSetTagFromFileNamePatternAction;
import net.sourceforge.atunes.kernel.actions.AutoSetTitlesAction;
import net.sourceforge.atunes.kernel.actions.AutoSetTracksAction;
import net.sourceforge.atunes.kernel.actions.ClearPlayListAction;
import net.sourceforge.atunes.kernel.actions.CreatePlayListWithSelectedAlbumsAction;
import net.sourceforge.atunes.kernel.actions.CreatePlayListWithSelectedArtistsAction;
import net.sourceforge.atunes.kernel.actions.EditTagAction;
import net.sourceforge.atunes.kernel.actions.LoadPlayListAction;
import net.sourceforge.atunes.kernel.actions.MoveDownAction;
import net.sourceforge.atunes.kernel.actions.MoveToBottomAction;
import net.sourceforge.atunes.kernel.actions.MoveToTopAction;
import net.sourceforge.atunes.kernel.actions.MoveUpAction;
import net.sourceforge.atunes.kernel.actions.OpenFolderAction;
import net.sourceforge.atunes.kernel.actions.PlayAction;
import net.sourceforge.atunes.kernel.actions.RemoveFromPlayListAction;
import net.sourceforge.atunes.kernel.actions.SavePlayListAction;
import net.sourceforge.atunes.kernel.actions.SetPlayListSelectionAsFavoriteAlbumAction;
import net.sourceforge.atunes.kernel.actions.SetPlayListSelectionAsFavoriteArtistAction;
import net.sourceforge.atunes.kernel.actions.SetPlayListSelectionAsFavoriteSongAction;
import net.sourceforge.atunes.kernel.actions.ShowPlayListItemInfoAction;
import net.sourceforge.atunes.kernel.actions.ShufflePlayListAction;
import net.sourceforge.atunes.kernel.actions.TogglePlayListFilterAction;
import net.sourceforge.atunes.kernel.modules.draganddrop.PlayListDragableRow;
import net.sourceforge.atunes.kernel.modules.playlist.PlayListHandler;
import net.sourceforge.atunes.model.AudioObject;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The play list table.
 */
public class PlayListTable extends JTable implements DragSourceListener, DragGestureListener {

    /**
     * The Enum PlayState.
     */
    public enum PlayState {

        STOPPED, PLAYING, PAUSED,
        /**
         * When it's not the active play list
         */
        NONE;

        public static ImageIcon getPlayStateIcon(PlayState state) {
            switch (state) {
            case PLAYING:
                return ImageLoader.PLAY_TINY;
            case STOPPED:
                return ImageLoader.STOP_TINY;
            case PAUSED:
                return ImageLoader.PAUSE_TINY;
            case NONE:
                return ImageLoader.EMPTY;
            default:
                return ImageLoader.EMPTY;
            }
        }
    }

    private static final long serialVersionUID = 9209069236823917569L;

    private PlayState playState = PlayState.STOPPED;
    private JPopupMenu menu;
    JPopupMenu rightMenu;
    private JMenuItem arrangeColumns;
    List<PlayListColumnClickedListener> listeners = new ArrayList<PlayListColumnClickedListener>();

    /**
     * Drag source for this play list to drag songs to device
     */
    private DragSource dragSource;

    /**
     * Instantiates a new play list table.
     */
    public PlayListTable() {
        super();
        setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        setShowGrid(false);
        setDropMode(DropMode.ON);

        // Add mouse click listener on table header
        getTableHeader().addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                // Use left button to sort
                if (e.getButton() == MouseEvent.BUTTON1) {
                    PlayListColumnModel colModel = (PlayListColumnModel) getColumnModel();
                    int column = colModel.getColumnIndexAtPosition(e.getX());
                    if (column >= 0) {
                        Column columnClicked = ((PlayListColumnModel) getColumnModel()).getColumnObject(column);
                        for (int i = 0; i < listeners.size(); i++) {
                            listeners.get(i).columnClicked(columnClicked);
                        }
                    }
                }
                // Use right button to arrange columns
                else if (e.getButton() == MouseEvent.BUTTON3) {
                    rightMenu.show(PlayListTable.this.getTableHeader(), e.getX(), e.getY());
                }
            }
        });

        // Set table model
        setModel(new PlayListTableModel());

        // Set column model
        setColumnModel(new PlayListColumnModel(this));

        // Disable autoresize, as we will control it
        setAutoResizeMode(JTable.AUTO_RESIZE_OFF);

        // Set renderers
        PlayListRenderers.addRenderers(this);

        // Remove enter key event, which moves selection down
        getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT).put(KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), "none");

        // Remove F2 key event
        InputMap im = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
        KeyStroke f2 = KeyStroke.getKeyStroke(KeyEvent.VK_F2, 0);
        im.put(f2, "none");

        rightMenu = new JPopupMenu();
        arrangeColumns = new JMenuItem(LanguageTool.getString("ARRANGE_COLUMNS"));
        rightMenu.add(arrangeColumns);

        menu = new JPopupMenu();

        menu.add(Actions.getAction(PlayAction.class));
        menu.add(Actions.getAction(ShowPlayListItemInfoAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(OpenFolderAction.class));
        menu.add(new JSeparator());
        JMenu tagMenu = setMenu(new JMenu(LanguageTool.getString("TAGS")));
        tagMenu.add(Actions.getAction(EditTagAction.class));
        tagMenu.add(new JSeparator());
        tagMenu.add(Actions.getAction(AutoSetTagFromFileNamePatternAction.class));
        tagMenu.add(new JSeparator());
        tagMenu.add(Actions.getAction(AutoSetLyricsAction.class));
        tagMenu.add(Actions.getAction(AutoSetTitlesAction.class));
        tagMenu.add(Actions.getAction(AutoSetTracksAction.class));
        tagMenu.add(Actions.getAction(AutoSetGenresAction.class));
        tagMenu.add(Actions.getAction(AutoSetCoversAction.class));
        menu.add(tagMenu);
        menu.add(new JSeparator());
        menu.add(Actions.getAction(SavePlayListAction.class));
        menu.add(Actions.getAction(LoadPlayListAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(RemoveFromPlayListAction.class));
        menu.add(Actions.getAction(ClearPlayListAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(MoveToTopAction.class));
        menu.add(Actions.getAction(MoveUpAction.class));
        menu.add(Actions.getAction(MoveDownAction.class));
        menu.add(Actions.getAction(MoveToBottomAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(ShufflePlayListAction.class));
        menu.add(new JSeparator());
        JMenu smartPlayList = new JMenu(LanguageTool.getString("SMART_PLAYLIST"));
        smartPlayList.add(Actions.getAction(Add10RandomSongsAction.class));
        smartPlayList.add(Actions.getAction(Add50RandomSongsAction.class));
        smartPlayList.add(Actions.getAction(Add100RandomSongsAction.class));
        smartPlayList.add(new JSeparator());
        smartPlayList.add(Actions.getAction(Add10SongsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add50SongsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add100SongsMostPlayedAction.class));
        smartPlayList.add(new JSeparator());
        smartPlayList.add(Actions.getAction(Add1AlbumsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add5AlbumsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add10AlbumsMostPlayedAction.class));
        smartPlayList.add(new JSeparator());
        smartPlayList.add(Actions.getAction(Add1ArtistsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add5ArtistsMostPlayedAction.class));
        smartPlayList.add(Actions.getAction(Add10ArtistsMostPlayedAction.class));
        smartPlayList.add(new JSeparator());
        smartPlayList.add(Actions.getAction(Add10UnplayedSongsAction.class));
        smartPlayList.add(Actions.getAction(Add50UnplayedSongsAction.class));
        smartPlayList.add(Actions.getAction(Add100UnplayedSongsAction.class));
        menu.add(smartPlayList);
        menu.add(new JSeparator());
        menu.add(Actions.getAction(SetPlayListSelectionAsFavoriteSongAction.class));
        menu.add(Actions.getAction(SetPlayListSelectionAsFavoriteAlbumAction.class));
        menu.add(Actions.getAction(SetPlayListSelectionAsFavoriteArtistAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(CreatePlayListWithSelectedArtistsAction.class));
        menu.add(Actions.getAction(CreatePlayListWithSelectedAlbumsAction.class));
        menu.add(new JSeparator());
        menu.add(Actions.getAction(TogglePlayListFilterAction.class));
        GuiUtils.applyComponentOrientation(menu);

        // Create drag source and set listener
        dragSource = new DragSource();
        dragSource.createDefaultDragGestureRecognizer(this, DnDConstants.ACTION_COPY, this);
    }

    /**
     * Adds the play list column clicked listener.
     * 
     * @param l
     *            the l
     */
    public void addPlayListColumnClickedListener(PlayListColumnClickedListener l) {
        listeners.add(l);
    }

    /**
     * Gets the arrange columns.
     * 
     * @return the arrangeColumns
     */
    public JMenuItem getArrangeColumns() {
        return arrangeColumns;
    }

    /**
     * Gets the menu.
     * 
     * @return the menu
     */
    public JPopupMenu getMenu() {
        return menu;
    }

    /**
     * Gets the play state.
     * 
     * @return the play state
     */
    public PlayState getPlayState() {
        return playState;
    }

    /**
     * Sets the menu.
     * 
     * @param item
     *            the item
     * 
     * @return the j menu
     */
    private JMenu setMenu(JMenu item) {
        item.setFont(Fonts.PLAY_LIST_FONT);
        return item;
    }

    /**
     * Sets the play state.
     * 
     * @param playState
     *            the new play state
     */
    public void setPlayState(PlayState playState) {
        this.playState = playState;
        revalidate();
        repaint();
    }

    @Override
    public void dragDropEnd(DragSourceDropEvent dsde) {
    }

    @Override
    public void dragEnter(DragSourceDragEvent dsde) {
    }

    @Override
    public void dragExit(DragSourceEvent dse) {
    }

    @Override
    public void dragGestureRecognized(DragGestureEvent dge) {
        // Only allow drag events initiated with left mouse button
        InputEvent event = dge.getTriggerEvent();
        if (!(event instanceof MouseEvent) || ((MouseEvent) event).getButton() != MouseEvent.BUTTON1) {
            return;
        }

        // Get selected rows, add PlayListDragableRow objects to a list and start a drag event
        int[] selectedRows = getSelectedRows();
        List<Object> itemsToDrag = new ArrayList<Object>();
        for (int i : selectedRows) {
            AudioObject obj = PlayListHandler.getInstance().getCurrentPlayList(true).get(i);
            itemsToDrag.add(new PlayListDragableRow(obj, i));
        }
        TransferableList<Object> items = new TransferableList<Object>(itemsToDrag);
        dragSource.startDrag(dge, DragSource.DefaultCopyDrop, items, this);
    }

    @Override
    public void dragOver(DragSourceDragEvent dsde) {
    }

    @Override
    public void dropActionChanged(DragSourceDragEvent dsde) {
    }
}
